@@ -61,10 +61,10 @@ gni_search <- function(search_term = NULL, per_page = NULL, page = NULL,
 	if (justtotal) {
 	  out$name_strings_total
 	} else {
-	  df <- ldply(out$name_strings, function(x)
-	    t(data.frame(c( checknull(x[["name"]]), checknull(x[["id"]]),
+	  df <- dt2df(lapply(out$name_strings, function(x)
+	    data.frame(t(data.frame(c( checknull(x[["name"]]), checknull(x[["id"]]),
 	                    checknull(x[["lsid"]]), checknull(x[["uuid_hex"]]),
-	                    checknull(x[["resource_url"]]) ))))
+	                    checknull(x[["resource_url"]]) ))))), idcol = FALSE)
 	  df <- colClasses(df, "character")
 	  if (NROW(df) != 0) {
 	    names(df) <- c("name","id","lsid","uuid_hex","resource_url")
