@@ -12,7 +12,6 @@ context("classification")
 #
 # is_up()
 # is_up(which = "eol")
-# is_up(which = "col")
 # is_up(which = "ncbi")
 #
 # skip_if <- function(x){
@@ -22,21 +21,13 @@ context("classification")
 # }
 
 # eolids <- get_tsn(c("Chironomus riparius", "aaa vva"), messages = FALSE)
-# colids <- get_colid(c("Chironomus riparius", "aaa vva"), messages = FALSE)
 # tpsids <- get_tpsid(sciname=c("Helianthus excubitor", "aaa vva"), messages = FALSE)
 # clas_eolids <- classification(eolids, messages = FALSE)
-# clas_colids <- classification(colids)
 # clas_tpids <- classification(tpsids, messages = FALSE)
 
 # clas_eol <- classification(c("Helianthus petiolaris Nutt.", "aaa vva"), db = 'eol')
 # names(clas_eol) <- NULL
 
-# clas_col <- suppressMessages(classification(c("Puma concolor", "aaa vva"), db = 'col'))
-# names(clas_col) <- NULL
-# colids <- get_colid(c("Puma concolor", "aaa vva"), messages = FALSE)
-# clas_colids <- classification(colids)
-# names(clas_colids) <- NULL
-
 # clas_tp <- suppressMessages(classification(c("Helianthus excubitor", "aaa vva"), db = 'tropicos'))
 # names(clas_tp) <- NULL
 
@@ -55,7 +46,6 @@ test_that("classification returns the correct values and classes", {
 	expect_that(clas_ncbi[[2]], equals(NA))
 	expect_that(clas_itis[[2]], equals(NA))
 # 	expect_that(clas_eol[[2]], equals(NA))
-# 	expect_that(clas_col[[2]], equals(NA))
 # 	expect_that(clas_tp[[2]], equals(NA))
 
 	expect_is(clas_ncbi, "classification")
@@ -70,10 +60,6 @@ test_that("classification returns the correct values and classes", {
 # 	expect_that(clas_eol[[1]], is_a("data.frame"))
 # 	expect_that(length(clas_eol), equals(2))
 
-# 	expect_that(clas_col, is_a("list"))
-# 	expect_that(clas_col[[1]], is_a("data.frame"))
-# 	expect_that(length(clas_col), equals(2))
-
 # 	expect_that(clas_tp, is_a("classification"))
 # 	expect_that(clas_tp[[1]], is_a("data.frame"))
 # 	expect_that(length(clas_tp), equals(2))
@@ -91,7 +77,6 @@ test_that("classification returns the correct values and classes", {
   expect_equal(clas_tsns, clas_itis)
 #   expect_identical(clas_eolids, clas_ncbi)
   #### FIX THESE TWO, SHOULD BE MATCHING
-  # expect_identical(clas_colids, clas_col)
 #   expect_identical(clas_tpids, clas_tp)
 })
 
@@ -169,7 +154,6 @@ test_that("all rank character strings are lower case (all letters)", {
     dd <- classification(2441176, db = 'gbif', messages = FALSE)
     #ee <- classification(25509881, db = 'tropicos', messages = FALSE)
     #ff <- classification("NBNSYS0000004786", db = 'nbn', messages = FALSE)
-    gg <- classification("Chironomus riparius", db = 'col', messages = FALSE)
   })
 
   expect_false(all(grepl("[A-Z]", aa[[1]]$rank)))
@@ -178,7 +162,6 @@ test_that("all rank character strings are lower case (all letters)", {
   expect_false(all(grepl("[A-Z]", dd[[1]]$rank)))
   #expect_false(all(grepl("[A-Z]", ee[[1]]$rank)))
   #expect_false(all(grepl("[A-Z]", ff[[1]]$rank)))
-  expect_false(all(grepl("[A-Z]", gg[[1]]$rank)))
 })
 
 
@@ -189,7 +172,6 @@ test_that("rows parameter, when used, works", {
     b <- classification("Asdfafsfd", db = 'itis', rows = 1, messages = FALSE)
     d <- classification("Asdfafsfd", db = 'gbif', rows = 1, messages = FALSE)
     e <- classification("Asdfafsfd", db = 'eol', rows = 1, messages = FALSE)
-    f <- sw(classification("Asdfafsfd", db = 'col', rows = 1, messages = FALSE))
     g <- classification("Asdfafsfd", db = 'tropicos', rows = 1, messages = FALSE)
     h <- classification("Asdfafsfd", db = 'nbn', rows = 1, messages = FALSE)
   })
@@ -198,7 +180,6 @@ test_that("rows parameter, when used, works", {
   expect_is(b, "classification")
   expect_is(d, "classification")
   expect_is(e, "classification")
-  expect_is(f, "classification")
   expect_is(g, "classification")
   expect_is(h, "classification")
 })
